@@ -19,9 +19,9 @@ import re
 
 from oslo_utils import strutils
 
+from cinderclient._i18n import _
 from cinderclient import exceptions
 from cinderclient import utils
-from cinderclient._i18n import _
 
 LOG = logging.getLogger(__name__)
 
@@ -29,7 +29,7 @@ LOG = logging.getLogger(__name__)
 # key is a deprecated version and value is an alternative version.
 DEPRECATED_VERSIONS = {"1": "2"}
 DEPRECATED_VERSION = "2.0"
-MAX_VERSION = "3.33"
+MAX_VERSION = "3.44"
 MIN_VERSION = "3.0"
 
 _SUBSTITUTIONS = {}
@@ -235,7 +235,14 @@ def get_api_version(version_string):
 
 
 def _get_server_version_range(client):
-    versions = client.services.server_api_version()
+    try:
+        versions = client.services.server_api_version()
+    except AttributeError:
+        # Wrong client was used, translate to something helpful.
+        raise exceptions.UnsupportedVersion(
+            _('Invalid client version %s to get server version range. Only '
+              'the v3 client is supported for this operation.') %
+            client.version)
 
     if not versions:
         return APIVersion(), APIVersion()
