@@ -43,18 +43,20 @@ import fixtures
 import mock
 from requests_mock.contrib import fixture as requests_mock_fixture
 import six
+from six.moves.urllib import parse
 
+import cinderclient
+from cinderclient import base
 from cinderclient import client
 from cinderclient import exceptions
 from cinderclient import shell
 from cinderclient import utils as cinderclient_utils
-from cinderclient.v3 import volumes
 from cinderclient.v3 import volume_snapshots
+from cinderclient.v3 import volumes
+
+from cinderclient.tests.unit.fixture_data import keystone_client
 from cinderclient.tests.unit import utils
 from cinderclient.tests.unit.v3 import fakes
-from cinderclient.tests.unit.fixture_data import keystone_client
-
-from six.moves.urllib import parse
 
 
 @ddt.ddt
@@ -229,6 +231,10 @@ class ShellTest(utils.TestCase):
         # NOTE(jdg): we default to detail currently
         self.assert_called('GET', '/volumes/detail')
 
+    def test_summary(self):
+        self.run_command('--os-volume-api-version 3.12 summary')
+        self.assert_called('GET', '/volumes/summary')
+
     def test_list_with_group_id_before_3_10(self):
         self.assertRaises(exceptions.UnsupportedAttribute,
                           self.run_command,
@@ -916,3 +922,71 @@ class ShellTest(utils.TestCase):
                          'service-set-log %s --binary %s --server %s '
                          '--prefix %s' % (level, binary, server, prefix))
         set_levels_mock.assert_called_once_with(level, binary, server, prefix)
+
+    @mock.patch('cinderclient.shell_utils._poll_for_status')
+    def test_create_with_poll(self, poll_method):
+        self.run_command('create --poll 1')
+        self.assert_called_anytime('GET', '/volumes/1234')
+        volume = self.shell.cs.volumes.get('1234')
+        info = dict()
+        info.update(volume._info)
+        info.pop('links', None)
+        self.assertEqual(1, poll_method.call_count)
+        timeout_period = 3600
+        poll_method.assert_has_calls([mock.call(self.shell.cs.volumes.get,
+            1234, info, 'creating', ['available'], timeout_period,
+            self.shell.cs.client.global_request_id,
+            self.shell.cs.messages)])
+
+    @mock.patch('cinderclient.shell_utils.time')
+    def test_poll_for_status(self, mock_time):
+        poll_period = 2
+        some_id = "some-id"
+        global_request_id = "req-someid"
+        action = "some"
+        updated_objects = (
+            base.Resource(None, info={"not_default_field": "creating"}),
+            base.Resource(None, info={"not_default_field": "available"}))
+        poll_fn = mock.MagicMock(side_effect=updated_objects)
+        cinderclient.shell_utils._poll_for_status(
+            poll_fn = poll_fn,
+            obj_id = some_id,
+            global_request_id = global_request_id,
+            messages = base.Resource(None, {}),
+            info = {},
+            action = action,
+            status_field = "not_default_field",
+            final_ok_states = ['available'],
+            timeout_period=3600)
+        self.assertEqual([mock.call(poll_period)] * 2,
+                mock_time.sleep.call_args_list)
+        self.assertEqual([mock.call(some_id)] * 2, poll_fn.call_args_list)
+
+    @mock.patch('cinderclient.v3.messages.MessageManager.list')
+    @mock.patch('cinderclient.shell_utils.time')
+    def test_poll_for_status_error(self, mock_time, mock_message_list):
+        poll_period = 2
+        some_id = "some_id"
+        global_request_id = "req-someid"
+        action = "some"
+        updated_objects = (
+            base.Resource(None, info={"not_default_field": "creating"}),
+            base.Resource(None, info={"not_default_field": "error"}))
+        poll_fn = mock.MagicMock(side_effect=updated_objects)
+        msg_object = base.Resource(cinderclient.v3.messages.MessageManager,
+                info = {"user_message": "ERROR!"})
+        mock_message_list.return_value = (msg_object,)
+        self.assertRaises(exceptions.ResourceInErrorState,
+                cinderclient.shell_utils._poll_for_status,
+                poll_fn=poll_fn,
+                obj_id=some_id,
+                global_request_id=global_request_id,
+                messages=cinderclient.v3.messages.MessageManager(api=3.34),
+                info=dict(),
+                action=action,
+                final_ok_states=['available'],
+                status_field="not_default_field",
+                timeout_period=3600)
+        self.assertEqual([mock.call(poll_period)] * 2,
+                mock_time.sleep.call_args_list)
+        self.assertEqual([mock.call(some_id)] * 2, poll_fn.call_args_list)
