@@ -19,6 +19,7 @@ from __future__ import print_function
 import argparse
 import collections
 import os
+import sys
 
 from oslo_utils import strutils
 import six
@@ -139,7 +140,7 @@ def do_backup_list(cs, args):
            action='store_true',
            help='Show detailed information about pools.')
 @utils.arg('--filters',
-           type=str,
+           type=six.text_type,
            nargs='*',
            start_version='3.33',
            metavar='<key=value>',
@@ -503,6 +504,9 @@ def do_reset_state(cs, args):
            help=('Allow volume to be attached more than once.'
                  ' Default=False'),
            default=False)
+@utils.arg('--poll',
+           action="store_true",
+           help=('Wait for volume creation until it completes.'))
 def do_create(cs, args):
     """Creates a volume."""
 
@@ -563,6 +567,12 @@ def do_create(cs, args):
         info['readonly'] = info['metadata']['readonly']
 
     info.pop('links', None)
+
+    if args.poll:
+        timeout_period = os.environ.get("POLL_TIMEOUT_PERIOD", 3600)
+        shell_utils._poll_for_status(cs.volumes.get, volume.id, info, 'creating', ['available'],
+                timeout_period, cs.client.global_request_id, cs.messages)
+
     utils.print_dict(info)
 
 
@@ -600,6 +610,27 @@ def do_metadata(cs, args):
                                    reverse=True))
 
 
+@api_versions.wraps('3.12')
+@utils.arg('--all-tenants',
+           dest='all_tenants',
+           metavar='<0|1>',
+           nargs='?',
+           type=int,
+           const=1,
+           default=utils.env('ALL_TENANTS', default=0),
+           help='Shows details for all tenants. Admin only.')
+def do_summary(cs, args):
+    """Get volumes summary."""
+    all_tenants = args.all_tenants
+    info = cs.volumes.summary(all_tenants)
+
+    formatters = ['total_size', 'total_count']
+    if cs.api_version >= api_versions.APIVersion("3.36"):
+        formatters.append('metadata')
+
+    utils.print_dict(info['volume-summary'], formatters=formatters)
+
+
 @api_versions.wraps('3.11')
 def do_group_type_list(cs, args):
     """Lists available 'group types'. (Admin only will see private types)"""
@@ -756,6 +787,10 @@ def do_group_type_key(cs, args):
            metavar='<per_volume_gigabytes>',
            type=int, default=None,
            help='Set max volume size limit. Default=None.')
+@utils.arg('--skip-validation',
+           metavar='<skip_validation>',
+           default=False,
+           help='Skip validate the existing resource quota. Default=False.')
 def do_quota_update(cs, args):
     """Updates quotas for a tenant."""
 
@@ -1902,6 +1937,16 @@ def do_attachment_delete(cs, args):
         cs.attachments.delete(attachment)
 
 
+@api_versions.wraps('3.44')
+@utils.arg('attachment',
+           metavar='<attachment>', nargs='+',
+           help='ID of attachment or attachments to delete.')
+def do_attachment_complete(cs, args):
+    """Complete an attachment for a cinder volume."""
+    for attachment in args.attachment:
+        cs.attachments.complete(attachment)
+
+
 @api_versions.wraps('3.0')
 def do_version_list(cs, args):
     """List all API versions."""
